@@ -50,15 +50,17 @@ setMethod(
   signature=signature(object="pfilterd_pomp"),
   definition=function (object, vars, ...,
     format = c("array", "data.frame")) {
-    if (missing(vars)) vars <- rownames(object@filter.traj)
-    format <- match.arg(format)
-    if (format == "array") {
-      object@filter.traj[vars,,,drop=FALSE]
+    if (missing(vars)) {
+      x <- object@filter.traj
     } else {
-      x <- melt(object@filter.traj[vars,,,drop=FALSE])
-      x$time <- time(object,t0=TRUE)[as.integer(x$time)]
-      x
+      x <- object@filter.traj[vars,,,drop=FALSE]
     }
+    format <- match.arg(format)
+    if (format == "data.frame") {
+      x <- melt(x)
+      x$time <- time(object,t0=TRUE)[as.integer(x$time)]
+    }
+    x
   }
 )
 
