@@ -70,7 +70,7 @@ setMethod(
         s[,c(object@timename,".id","name","value")],
         w[,c(object@timename,".id","name","value")]
       )
-      x <- x[order(x$time,x$.id),]
+      x <- x[order(x[[object@timename]],x$.id),]
       row.names(x) <- NULL
       x
     } else {
@@ -84,7 +84,6 @@ setMethod(
 )
 
 ##' @rdname saved_states
-##' @importFrom dplyr bind_rows
 ##' @export
 setMethod(
   "saved_states",
@@ -94,7 +93,7 @@ setMethod(
     format <- match.arg(format)
     x <- lapply(object,saved_states,...,format=format)
     if (format == "data.frame") {
-      x <- bind_rows(x,.id=".L1")
+      x <- rbind_fill(x,.id=".L1")
     }
     x
   }
